/* contacts-contact-frame.c generated by valac 0.32.0.15-114e9, the Vala compiler
 * generated from contacts-contact-frame.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 8 -*- */
/*
 * Copyright (C) 2011 Alexander Larsson <alexl@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <pango/pango.h>
#include <atk/atk.h>
#include <glib/gi18n-lib.h>
#include <cairo.h>
#include <folks/folks.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <pango/pangocairo.h>


#define CONTACTS_TYPE_CONTACT_FRAME (contacts_contact_frame_get_type ())
#define CONTACTS_CONTACT_FRAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_CONTACT_FRAME, ContactsContactFrame))
#define CONTACTS_CONTACT_FRAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_CONTACT_FRAME, ContactsContactFrameClass))
#define CONTACTS_IS_CONTACT_FRAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_CONTACT_FRAME))
#define CONTACTS_IS_CONTACT_FRAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_CONTACT_FRAME))
#define CONTACTS_CONTACT_FRAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_CONTACT_FRAME, ContactsContactFrameClass))

typedef struct _ContactsContactFrame ContactsContactFrame;
typedef struct _ContactsContactFrameClass ContactsContactFrameClass;
typedef struct _ContactsContactFramePrivate ContactsContactFramePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define CONTACTS_TYPE_CONTACT (contacts_contact_get_type ())
#define CONTACTS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_CONTACT, ContactsContact))
#define CONTACTS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_CONTACT, ContactsContactClass))
#define CONTACTS_IS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_CONTACT))
#define CONTACTS_IS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_CONTACT))
#define CONTACTS_CONTACT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_CONTACT, ContactsContactClass))

typedef struct _ContactsContact ContactsContact;
typedef struct _ContactsContactClass ContactsContactClass;
#define __vala_PangoFontDescription_free0(var) ((var == NULL) ? NULL : (var = (_vala_PangoFontDescription_free (var), NULL)))

struct _ContactsContactFrame {
	GtkFrame parent_instance;
	ContactsContactFramePrivate * priv;
};

struct _ContactsContactFrameClass {
	GtkFrameClass parent_class;
};

struct _ContactsContactFramePrivate {
	gint size;
	gchar* text;
	GdkPixbuf* pixbuf;
	PangoLayout* layout;
	gint text_height;
};


static gpointer contacts_contact_frame_parent_class = NULL;

GType contacts_contact_frame_get_type (void) G_GNUC_CONST;
#define CONTACTS_CONTACT_FRAME_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CONTACTS_TYPE_CONTACT_FRAME, ContactsContactFramePrivate))
enum  {
	CONTACTS_CONTACT_FRAME_DUMMY_PROPERTY
};
ContactsContactFrame* contacts_contact_frame_new (gint size, gboolean with_button);
ContactsContactFrame* contacts_contact_frame_construct (GType object_type, gint size, gboolean with_button);
static void ___lambda28_ (ContactsContactFrame* self);
static void ____lambda28__gtk_button_clicked (GtkButton* _sender, gpointer self);
gboolean contacts_contact_frame_draw_image (ContactsContactFrame* self, cairo_t* cr);
static gboolean _contacts_contact_frame_draw_image_gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
void contacts_contact_frame_set_pixbuf (ContactsContactFrame* self, GdkPixbuf* a_pixbuf);
GdkPixbuf* contacts_contact_frame_icon (GdkPixbuf* icon);
GType contacts_contact_get_type (void) G_GNUC_CONST;
void contacts_contact_frame_set_image (ContactsContactFrame* self, FolksAvatarDetails* details, ContactsContact* contact);
GdkPixbuf* contacts_contact_draw_fallback_avatar (gint size, ContactsContact* contact);
void contacts_contact_frame_set_text (ContactsContactFrame* self, const gchar* text_, gint text_height_);
static void _vala_PangoFontDescription_free (PangoFontDescription* self);
void contacts_utils_cairo_rounded_box (cairo_t* cr, gint x, gint y, gint width, gint height, gint radius);
static void contacts_contact_frame_finalize (GObject* obj);


static void ___lambda28_ (ContactsContactFrame* self) {
#line 47 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_signal_emit_by_name (self, "clicked");
#line 110 "contacts-contact-frame.c"
}


static void ____lambda28__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	___lambda28_ ((ContactsContactFrame*) self);
#line 117 "contacts-contact-frame.c"
}


static gboolean _contacts_contact_frame_draw_image_gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = contacts_contact_frame_draw_image ((ContactsContactFrame*) self, cr);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	return result;
#line 126 "contacts-contact-frame.c"
}


ContactsContactFrame* contacts_contact_frame_construct (GType object_type, gint size, gboolean with_button) {
	ContactsContactFrame * self = NULL;
	gint _tmp0_ = 0;
	GtkImage* image = NULL;
	GtkImage* _tmp1_ = NULL;
	GtkImage* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gboolean _tmp5_ = FALSE;
	GtkImage* _tmp19_ = NULL;
	GtkImage* _tmp20_ = NULL;
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	self = (ContactsContactFrame*) g_object_new (object_type, NULL);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp0_ = size;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	self->priv->size = _tmp0_;
#line 35 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp1_ = (GtkImage*) gtk_image_new ();
#line 35 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_object_ref_sink (_tmp1_);
#line 35 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	image = _tmp1_;
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp2_ = image;
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp3_ = size;
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp4_ = size;
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	gtk_widget_set_size_request ((GtkWidget*) _tmp2_, _tmp3_, _tmp4_);
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp5_ = with_button;
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	if (_tmp5_) {
#line 165 "contacts-contact-frame.c"
		GtkButton* button = NULL;
		GtkButton* _tmp6_ = NULL;
		GtkButton* _tmp7_ = NULL;
		AtkObject* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		GtkButton* _tmp10_ = NULL;
		GtkStyleContext* _tmp11_ = NULL;
		GtkButton* _tmp12_ = NULL;
		GtkButton* _tmp13_ = NULL;
		GtkButton* _tmp14_ = NULL;
		GtkImage* _tmp15_ = NULL;
		GtkButton* _tmp16_ = NULL;
		GtkButton* _tmp17_ = NULL;
#line 39 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp6_ = (GtkButton*) gtk_button_new ();
#line 39 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		g_object_ref_sink (_tmp6_);
#line 39 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		button = _tmp6_;
#line 40 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp7_ = button;
#line 40 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp8_ = gtk_widget_get_accessible ((GtkWidget*) _tmp7_);
#line 40 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp9_ = _ ("Change avatar");
#line 40 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		atk_object_set_name (_tmp8_, _tmp9_);
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp10_ = button;
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp11_ = gtk_widget_get_style_context ((GtkWidget*) _tmp10_);
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		gtk_style_context_add_class (_tmp11_, "contacts-square");
#line 42 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp12_ = button;
#line 42 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		gtk_button_set_relief (_tmp12_, GTK_RELIEF_NONE);
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp13_ = button;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		gtk_button_set_focus_on_click (_tmp13_, FALSE);
#line 44 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp14_ = button;
#line 44 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp15_ = image;
#line 44 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		gtk_container_add ((GtkContainer*) _tmp14_, (GtkWidget*) _tmp15_);
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp16_ = button;
#line 46 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		g_signal_connect_object (_tmp16_, "clicked", (GCallback) ____lambda28__gtk_button_clicked, self, 0);
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp17_ = button;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp17_);
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_g_object_unref0 (button);
#line 223 "contacts-contact-frame.c"
	} else {
		GtkImage* _tmp18_ = NULL;
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp18_ = image;
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp18_);
#line 230 "contacts-contact-frame.c"
	}
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp19_ = image;
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	gtk_widget_show ((GtkWidget*) _tmp19_);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp20_ = image;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_signal_connect_object ((GtkWidget*) _tmp20_, "draw", (GCallback) _contacts_contact_frame_draw_image_gtk_widget_draw, self, 0);
#line 58 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	gtk_frame_set_shadow_type ((GtkFrame*) self, GTK_SHADOW_NONE);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_g_object_unref0 (image);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	return self;
#line 246 "contacts-contact-frame.c"
}


ContactsContactFrame* contacts_contact_frame_new (gint size, gboolean with_button) {
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	return contacts_contact_frame_construct (CONTACTS_TYPE_CONTACT_FRAME, size, with_button);
#line 253 "contacts-contact-frame.c"
}


void contacts_contact_frame_set_pixbuf (ContactsContactFrame* self, GdkPixbuf* a_pixbuf) {
	GdkPixbuf* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
#line 61 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_return_if_fail (self != NULL);
#line 61 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_return_if_fail (a_pixbuf != NULL);
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp0_ = a_pixbuf;
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp1_ = contacts_contact_frame_icon (_tmp0_);
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_g_object_unref0 (self->priv->pixbuf);
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	self->priv->pixbuf = _tmp1_;
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 274 "contacts-contact-frame.c"
}


void contacts_contact_frame_set_image (ContactsContactFrame* self, FolksAvatarDetails* details, ContactsContact* contact) {
	GdkPixbuf* a_pixbuf = NULL;
	gboolean _tmp0_ = FALSE;
	FolksAvatarDetails* _tmp1_ = NULL;
	GdkPixbuf* _tmp16_ = NULL;
	GdkPixbuf* _tmp20_ = NULL;
	GError * _inner_error_ = NULL;
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_return_if_fail (self != NULL);
#line 67 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	a_pixbuf = NULL;
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp1_ = details;
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	if (_tmp1_ != NULL) {
#line 293 "contacts-contact-frame.c"
		FolksAvatarDetails* _tmp2_ = NULL;
		GLoadableIcon* _tmp3_ = NULL;
		GLoadableIcon* _tmp4_ = NULL;
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp2_ = details;
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp3_ = folks_avatar_details_get_avatar (_tmp2_);
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp4_ = _tmp3_;
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp0_ = _tmp4_ != NULL;
#line 305 "contacts-contact-frame.c"
	} else {
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp0_ = FALSE;
#line 309 "contacts-contact-frame.c"
	}
#line 68 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	if (_tmp0_) {
#line 313 "contacts-contact-frame.c"
		{
			GInputStream* stream = NULL;
			FolksAvatarDetails* _tmp5_ = NULL;
			GLoadableIcon* _tmp6_ = NULL;
			GLoadableIcon* _tmp7_ = NULL;
			gint _tmp8_ = 0;
			GInputStream* _tmp9_ = NULL;
			GdkPixbuf* _tmp10_ = NULL;
			GInputStream* _tmp11_ = NULL;
			gint _tmp12_ = 0;
			gint _tmp13_ = 0;
			GdkPixbuf* _tmp14_ = NULL;
			GdkPixbuf* _tmp15_ = NULL;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp5_ = details;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp6_ = folks_avatar_details_get_avatar (_tmp5_);
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp7_ = _tmp6_;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp8_ = self->priv->size;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp9_ = g_loadable_icon_load (_tmp7_, _tmp8_, NULL, NULL, &_inner_error_);
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			stream = _tmp9_;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 341 "contacts-contact-frame.c"
				goto __catch42_g_error;
			}
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp11_ = stream;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp12_ = self->priv->size;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp13_ = self->priv->size;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp14_ = gdk_pixbuf_new_from_stream_at_scale (_tmp11_, _tmp12_, _tmp13_, TRUE, NULL, &_inner_error_);
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp10_ = _tmp14_;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				_g_object_unref0 (stream);
#line 358 "contacts-contact-frame.c"
				goto __catch42_g_error;
			}
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp15_ = _tmp10_;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp10_ = NULL;
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_g_object_unref0 (a_pixbuf);
#line 72 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			a_pixbuf = _tmp15_;
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_g_object_unref0 (_tmp10_);
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_g_object_unref0 (stream);
#line 373 "contacts-contact-frame.c"
		}
		goto __finally42;
		__catch42_g_error:
		{
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			g_clear_error (&_inner_error_);
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_inner_error_ = NULL;
#line 382 "contacts-contact-frame.c"
		}
		__finally42:
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_g_object_unref0 (a_pixbuf);
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			g_clear_error (&_inner_error_);
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			return;
#line 395 "contacts-contact-frame.c"
		}
	}
#line 78 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp16_ = a_pixbuf;
#line 78 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	if (_tmp16_ == NULL) {
#line 402 "contacts-contact-frame.c"
		gint _tmp17_ = 0;
		ContactsContact* _tmp18_ = NULL;
		GdkPixbuf* _tmp19_ = NULL;
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp17_ = self->priv->size;
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp18_ = contact;
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp19_ = contacts_contact_draw_fallback_avatar (_tmp17_, _tmp18_);
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_g_object_unref0 (a_pixbuf);
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		a_pixbuf = _tmp19_;
#line 416 "contacts-contact-frame.c"
	}
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp20_ = a_pixbuf;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	contacts_contact_frame_set_pixbuf (self, _tmp20_);
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_g_object_unref0 (a_pixbuf);
#line 424 "contacts-contact-frame.c"
}


static void _vala_PangoFontDescription_free (PangoFontDescription* self) {
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_boxed_free (pango_font_description_get_type (), self);
#line 431 "contacts-contact-frame.c"
}


void contacts_contact_frame_set_text (ContactsContactFrame* self, const gchar* text_, gint text_height_) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	const gchar* _tmp3_ = NULL;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_return_if_fail (self != NULL);
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp0_ = text_;
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_g_free0 (self->priv->text);
#line 85 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	self->priv->text = _tmp1_;
#line 86 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp2_ = text_height_;
#line 86 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	self->priv->text_height = _tmp2_;
#line 87 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_g_object_unref0 (self->priv->layout);
#line 87 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	self->priv->layout = NULL;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp3_ = self->priv->text;
#line 88 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	if (_tmp3_ != NULL) {
#line 462 "contacts-contact-frame.c"
		const gchar* _tmp4_ = NULL;
		PangoLayout* _tmp5_ = NULL;
		PangoRectangle rect = {0};
		PangoRectangle _tmp6_ = {0};
		gint font_size = 0;
		gint _tmp7_ = 0;
#line 89 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp4_ = self->priv->text;
#line 89 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp5_ = gtk_widget_create_pango_layout ((GtkWidget*) self, _tmp4_);
#line 89 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_g_object_unref0 (self->priv->layout);
#line 89 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		self->priv->layout = _tmp5_;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp6_.x = 0;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		rect = _tmp6_;
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp7_ = self->priv->text_height;
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		font_size = (_tmp7_ - 4) + 1;
#line 485 "contacts-contact-frame.c"
		{
			gboolean _tmp8_ = FALSE;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			_tmp8_ = TRUE;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
			while (TRUE) {
#line 492 "contacts-contact-frame.c"
				gint _tmp12_ = 0;
				PangoFontDescription* fd = NULL;
				PangoFontDescription* _tmp13_ = NULL;
				PangoFontDescription* _tmp14_ = NULL;
				gint _tmp15_ = 0;
				PangoLayout* _tmp16_ = NULL;
				PangoFontDescription* _tmp17_ = NULL;
				PangoLayout* _tmp18_ = NULL;
				PangoRectangle _tmp19_ = {0};
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				if (!_tmp8_) {
#line 504 "contacts-contact-frame.c"
					PangoRectangle _tmp9_ = {0};
					gint _tmp10_ = 0;
					gint _tmp11_ = 0;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
					_tmp9_ = rect;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
					_tmp10_ = _tmp9_.width;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
					_tmp11_ = self->priv->size;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
					if (!(_tmp10_ > (_tmp11_ * PANGO_SCALE))) {
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
						break;
#line 518 "contacts-contact-frame.c"
					}
				}
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				_tmp8_ = FALSE;
#line 94 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				_tmp12_ = font_size;
#line 94 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				font_size = _tmp12_ - 1;
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				_tmp13_ = pango_font_description_new ();
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				fd = _tmp13_;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				_tmp14_ = fd;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				_tmp15_ = font_size;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				pango_font_description_set_absolute_size (_tmp14_, (gdouble) (_tmp15_ * PANGO_SCALE));
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				_tmp16_ = self->priv->layout;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				_tmp17_ = fd;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				pango_layout_set_font_description (_tmp16_, _tmp17_);
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				_tmp18_ = self->priv->layout;
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				pango_layout_get_extents (_tmp18_, NULL, &_tmp19_);
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				rect = _tmp19_;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
				__vala_PangoFontDescription_free0 (fd);
#line 551 "contacts-contact-frame.c"
			}
		}
	}
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 557 "contacts-contact-frame.c"
}


gboolean contacts_contact_frame_draw_image (ContactsContactFrame* self, cairo_t* cr) {
	gboolean result = FALSE;
	cairo_t* _tmp0_ = NULL;
	GdkPixbuf* _tmp1_ = NULL;
	PangoLayout* _tmp5_ = NULL;
	cairo_t* _tmp35_ = NULL;
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 104 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_return_val_if_fail (cr != NULL, FALSE);
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp0_ = cr;
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	cairo_save (_tmp0_);
#line 107 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp1_ = self->priv->pixbuf;
#line 107 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	if (_tmp1_ != NULL) {
#line 579 "contacts-contact-frame.c"
		cairo_t* _tmp2_ = NULL;
		GdkPixbuf* _tmp3_ = NULL;
		cairo_t* _tmp4_ = NULL;
#line 108 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp2_ = cr;
#line 108 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp3_ = self->priv->pixbuf;
#line 108 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		gdk_cairo_set_source_pixbuf (_tmp2_, _tmp3_, (gdouble) 0, (gdouble) 0);
#line 109 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp4_ = cr;
#line 109 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		cairo_paint (_tmp4_);
#line 593 "contacts-contact-frame.c"
	}
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp5_ = self->priv->layout;
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	if (_tmp5_ != NULL) {
#line 599 "contacts-contact-frame.c"
		cairo_t* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gint _tmp8_ = 0;
		cairo_t* _tmp9_ = NULL;
		cairo_t* _tmp10_ = NULL;
		cairo_t* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		gint _tmp15_ = 0;
		cairo_t* _tmp16_ = NULL;
		cairo_t* _tmp17_ = NULL;
		PangoRectangle rect = {0};
		PangoLayout* _tmp18_ = NULL;
		PangoRectangle _tmp19_ = {0};
		gdouble label_width = 0.0;
		PangoRectangle _tmp20_ = {0};
		gint _tmp21_ = 0;
		gdouble label_height = 0.0;
		PangoRectangle _tmp22_ = {0};
		gint _tmp23_ = 0;
		cairo_t* _tmp24_ = NULL;
		gint _tmp25_ = 0;
		gdouble _tmp26_ = 0.0;
		gdouble _tmp27_ = 0.0;
		gint _tmp28_ = 0;
		gint _tmp29_ = 0;
		gint _tmp30_ = 0;
		gdouble _tmp31_ = 0.0;
		gdouble _tmp32_ = 0.0;
		cairo_t* _tmp33_ = NULL;
		PangoLayout* _tmp34_ = NULL;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp6_ = cr;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp7_ = self->priv->size;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp8_ = self->priv->size;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		contacts_utils_cairo_rounded_box (_tmp6_, 0, 0, _tmp7_, _tmp8_, 4);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp9_ = cr;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		cairo_clip (_tmp9_);
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp10_ = cr;
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		cairo_set_source_rgba (_tmp10_, (gdouble) 0, (gdouble) 0, (gdouble) 0, 0.5);
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp11_ = cr;
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp12_ = self->priv->size;
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp13_ = self->priv->text_height;
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp14_ = self->priv->size;
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp15_ = self->priv->text_height;
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		cairo_rectangle (_tmp11_, (gdouble) 0, (gdouble) (_tmp12_ - _tmp13_), (gdouble) _tmp14_, (gdouble) _tmp15_);
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp16_ = cr;
#line 118 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		cairo_fill (_tmp16_);
#line 120 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp17_ = cr;
#line 120 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		cairo_set_source_rgb (_tmp17_, 1.0, 1.0, 1.0);
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp18_ = self->priv->layout;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		pango_layout_get_extents (_tmp18_, NULL, &_tmp19_);
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		rect = _tmp19_;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp20_ = rect;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp21_ = _tmp20_.width;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		label_width = _tmp21_ / ((gdouble) PANGO_SCALE);
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp22_ = rect;
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp23_ = _tmp22_.height;
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		label_height = _tmp23_ / ((gdouble) PANGO_SCALE);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp24_ = cr;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp25_ = self->priv->size;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp26_ = label_width;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp27_ = round ((_tmp25_ - _tmp26_) / 2.0);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp28_ = self->priv->size;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp29_ = self->priv->text_height;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp30_ = self->priv->text_height;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp31_ = label_height;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp32_ = floor ((_tmp30_ - _tmp31_) / 2.0);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		cairo_move_to (_tmp24_, _tmp27_, (_tmp28_ - _tmp29_) + _tmp32_);
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp33_ = cr;
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		_tmp34_ = self->priv->layout;
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
		pango_cairo_show_layout (_tmp33_, _tmp34_);
#line 712 "contacts-contact-frame.c"
	}
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_tmp35_ = cr;
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	cairo_restore (_tmp35_);
#line 131 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	result = TRUE;
#line 131 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	return result;
#line 722 "contacts-contact-frame.c"
}


static void contacts_contact_frame_class_init (ContactsContactFrameClass * klass) {
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	contacts_contact_frame_parent_class = g_type_class_peek_parent (klass);
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_type_class_add_private (klass, sizeof (ContactsContactFramePrivate));
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	G_OBJECT_CLASS (klass)->finalize = contacts_contact_frame_finalize;
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	g_signal_new ("clicked", CONTACTS_TYPE_CONTACT_FRAME, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 735 "contacts-contact-frame.c"
}


static void contacts_contact_frame_instance_init (ContactsContactFrame * self) {
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	self->priv = CONTACTS_CONTACT_FRAME_GET_PRIVATE (self);
#line 742 "contacts-contact-frame.c"
}


static void contacts_contact_frame_finalize (GObject* obj) {
	ContactsContactFrame * self;
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CONTACTS_TYPE_CONTACT_FRAME, ContactsContactFrame);
#line 25 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_g_free0 (self->priv->text);
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_g_object_unref0 (self->priv->pixbuf);
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	_g_object_unref0 (self->priv->layout);
#line 23 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-contact-frame.vala"
	G_OBJECT_CLASS (contacts_contact_frame_parent_class)->finalize (obj);
#line 758 "contacts-contact-frame.c"
}


GType contacts_contact_frame_get_type (void) {
	static volatile gsize contacts_contact_frame_type_id__volatile = 0;
	if (g_once_init_enter (&contacts_contact_frame_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ContactsContactFrameClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) contacts_contact_frame_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ContactsContactFrame), 0, (GInstanceInitFunc) contacts_contact_frame_instance_init, NULL };
		GType contacts_contact_frame_type_id;
		contacts_contact_frame_type_id = g_type_register_static (gtk_frame_get_type (), "ContactsContactFrame", &g_define_type_info, 0);
		g_once_init_leave (&contacts_contact_frame_type_id__volatile, contacts_contact_frame_type_id);
	}
	return contacts_contact_frame_type_id__volatile;
}



